@@ -3,9 +3,11 @@
 pub use error::*;
 pub use protocol::*;
 pub use reporter::*;
+pub use utils::*;
 
 mod chain;
 mod error;
 mod protocol;
 mod reporter;
 mod source_impls;
+mod utils;
